/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BrowserApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#account_id BrowserApplication#account_id}
    */
    readonly accountId?: number;
    /**
    * Configure cookies. The default is enabled: true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#cookies_enabled BrowserApplication#cookies_enabled}
    */
    readonly cookiesEnabled?: boolean | cdktf.IResolvable;
    /**
    * Configure distributed tracing in browser apps. The default is enabled: true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#distributed_tracing_enabled BrowserApplication#distributed_tracing_enabled}
    */
    readonly distributedTracingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#id BrowserApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Determines which browser loader is configured. The default is "SPA".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#loader_type BrowserApplication#loader_type}
    */
    readonly loaderType?: string;
    /**
    * The name of the application to monitor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application#name BrowserApplication#name}
    */
    readonly name: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application newrelic_browser_application}
*/
export declare class BrowserApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "newrelic_browser_application";
    /**
    * Create a new {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/browser_application newrelic_browser_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BrowserApplicationConfig
    */
    constructor(scope: Construct, id: string, config: BrowserApplicationConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _cookiesEnabled?;
    get cookiesEnabled(): boolean | cdktf.IResolvable;
    set cookiesEnabled(value: boolean | cdktf.IResolvable);
    resetCookiesEnabled(): void;
    get cookiesEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _distributedTracingEnabled?;
    get distributedTracingEnabled(): boolean | cdktf.IResolvable;
    set distributedTracingEnabled(value: boolean | cdktf.IResolvable);
    resetDistributedTracingEnabled(): void;
    get distributedTracingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get guid(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _loaderType?;
    get loaderType(): string;
    set loaderType(value: string);
    resetLoaderType(): void;
    get loaderTypeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
