/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NotificationChannelConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account id of the channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#account_id NotificationChannel#account_id}
    */
    readonly accountId?: number;
    /**
    * Indicates whether the channel is active.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#active NotificationChannel#active}
    */
    readonly active?: boolean | cdktf.IResolvable;
    /**
    * (Required) The id of the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#destination_id NotificationChannel#destination_id}
    */
    readonly destinationId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#id NotificationChannel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * (Required) The name of the channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#name NotificationChannel#name}
    */
    readonly name: string;
    /**
    * (Required) The type of the channel product. One of: (DISCUSSIONS, ERROR_TRACKING, IINT).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#product NotificationChannel#product}
    */
    readonly product: string;
    /**
    * (Required) The type of the channel. One of: (WEBHOOK, EMAIL, SERVICENOW_INCIDENTS, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA_CLASSIC, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#type NotificationChannel#type}
    */
    readonly type: string;
    /**
    * property block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#property NotificationChannel#property}
    */
    readonly property: NotificationChannelProperty[] | cdktf.IResolvable;
}
export interface NotificationChannelProperty {
    /**
    * Notification property display key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#display_value NotificationChannel#display_value}
    */
    readonly displayValue?: string;
    /**
    * Notification property key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#key NotificationChannel#key}
    */
    readonly key: string;
    /**
    * Notification property label.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#label NotificationChannel#label}
    */
    readonly label?: string;
    /**
    * Notification property value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel#value NotificationChannel#value}
    */
    readonly value: string;
}
export declare function notificationChannelPropertyToTerraform(struct?: NotificationChannelProperty | cdktf.IResolvable): any;
export declare class NotificationChannelPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NotificationChannelProperty | cdktf.IResolvable | undefined;
    set internalValue(value: NotificationChannelProperty | cdktf.IResolvable | undefined);
    private _displayValue?;
    get displayValue(): string;
    set displayValue(value: string);
    resetDisplayValue(): void;
    get displayValueInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _label?;
    get label(): string;
    set label(value: string);
    resetLabel(): void;
    get labelInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class NotificationChannelPropertyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NotificationChannelProperty[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NotificationChannelPropertyOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel newrelic_notification_channel}
*/
export declare class NotificationChannel extends cdktf.TerraformResource {
    static readonly tfResourceType = "newrelic_notification_channel";
    /**
    * Create a new {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_channel newrelic_notification_channel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NotificationChannelConfig
    */
    constructor(scope: Construct, id: string, config: NotificationChannelConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _active?;
    get active(): boolean | cdktf.IResolvable;
    set active(value: boolean | cdktf.IResolvable);
    resetActive(): void;
    get activeInput(): boolean | cdktf.IResolvable | undefined;
    private _destinationId?;
    get destinationId(): string;
    set destinationId(value: string);
    get destinationIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _product?;
    get product(): string;
    set product(value: string);
    get productInput(): string | undefined;
    get status(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _property;
    get property(): NotificationChannelPropertyList;
    putProperty(value: NotificationChannelProperty[] | cdktf.IResolvable): void;
    get propertyInput(): cdktf.IResolvable | NotificationChannelProperty[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
