/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NotificationDestinationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account ID under which to put the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#account_id NotificationDestination#account_id}
    */
    readonly accountId?: number;
    /**
    * Indicates whether the destination is active.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#active NotificationDestination#active}
    */
    readonly active?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#id NotificationDestination#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * (Required) The name of the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#name NotificationDestination#name}
    */
    readonly name: string;
    /**
    * (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#type NotificationDestination#type}
    */
    readonly type: string;
    /**
    * auth_basic block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#auth_basic NotificationDestination#auth_basic}
    */
    readonly authBasic?: NotificationDestinationAuthBasic;
    /**
    * auth_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#auth_token NotificationDestination#auth_token}
    */
    readonly authToken?: NotificationDestinationAuthToken;
    /**
    * property block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#property NotificationDestination#property}
    */
    readonly property: NotificationDestinationProperty[] | cdktf.IResolvable;
}
export interface NotificationDestinationAuthBasic {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#password NotificationDestination#password}
    */
    readonly password: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#user NotificationDestination#user}
    */
    readonly user: string;
}
export declare function notificationDestinationAuthBasicToTerraform(struct?: NotificationDestinationAuthBasicOutputReference | NotificationDestinationAuthBasic): any;
export declare class NotificationDestinationAuthBasicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NotificationDestinationAuthBasic | undefined;
    set internalValue(value: NotificationDestinationAuthBasic | undefined);
    private _password?;
    get password(): string;
    set password(value: string);
    get passwordInput(): string | undefined;
    private _user?;
    get user(): string;
    set user(value: string);
    get userInput(): string | undefined;
}
export interface NotificationDestinationAuthToken {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#prefix NotificationDestination#prefix}
    */
    readonly prefix?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#token NotificationDestination#token}
    */
    readonly token: string;
}
export declare function notificationDestinationAuthTokenToTerraform(struct?: NotificationDestinationAuthTokenOutputReference | NotificationDestinationAuthToken): any;
export declare class NotificationDestinationAuthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NotificationDestinationAuthToken | undefined;
    set internalValue(value: NotificationDestinationAuthToken | undefined);
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    get tokenInput(): string | undefined;
}
export interface NotificationDestinationProperty {
    /**
    * Notification property display key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#display_value NotificationDestination#display_value}
    */
    readonly displayValue?: string;
    /**
    * Notification property key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#key NotificationDestination#key}
    */
    readonly key: string;
    /**
    * Notification property label.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#label NotificationDestination#label}
    */
    readonly label?: string;
    /**
    * Notification property value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination#value NotificationDestination#value}
    */
    readonly value: string;
}
export declare function notificationDestinationPropertyToTerraform(struct?: NotificationDestinationProperty | cdktf.IResolvable): any;
export declare class NotificationDestinationPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NotificationDestinationProperty | cdktf.IResolvable | undefined;
    set internalValue(value: NotificationDestinationProperty | cdktf.IResolvable | undefined);
    private _displayValue?;
    get displayValue(): string;
    set displayValue(value: string);
    resetDisplayValue(): void;
    get displayValueInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _label?;
    get label(): string;
    set label(value: string);
    resetLabel(): void;
    get labelInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class NotificationDestinationPropertyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NotificationDestinationProperty[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NotificationDestinationPropertyOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination newrelic_notification_destination}
*/
export declare class NotificationDestination extends cdktf.TerraformResource {
    static readonly tfResourceType = "newrelic_notification_destination";
    /**
    * Create a new {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/notification_destination newrelic_notification_destination} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NotificationDestinationConfig
    */
    constructor(scope: Construct, id: string, config: NotificationDestinationConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _active?;
    get active(): boolean | cdktf.IResolvable;
    set active(value: boolean | cdktf.IResolvable);
    resetActive(): void;
    get activeInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastSent(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get status(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _authBasic;
    get authBasic(): NotificationDestinationAuthBasicOutputReference;
    putAuthBasic(value: NotificationDestinationAuthBasic): void;
    resetAuthBasic(): void;
    get authBasicInput(): NotificationDestinationAuthBasic | undefined;
    private _authToken;
    get authToken(): NotificationDestinationAuthTokenOutputReference;
    putAuthToken(value: NotificationDestinationAuthToken): void;
    resetAuthToken(): void;
    get authTokenInput(): NotificationDestinationAuthToken | undefined;
    private _property;
    get property(): NotificationDestinationPropertyList;
    putProperty(value: NotificationDestinationProperty[] | cdktf.IResolvable): void;
    get propertyInput(): cdktf.IResolvable | NotificationDestinationProperty[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
