/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SyntheticsPrivateLocationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the account in New Relic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location#account_id SyntheticsPrivateLocation#account_id}
    */
    readonly accountId?: number;
    /**
    * The private location description.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location#description SyntheticsPrivateLocation#description}
    */
    readonly description: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location#id SyntheticsPrivateLocation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the private location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location#name SyntheticsPrivateLocation#name}
    */
    readonly name: string;
    /**
    * The private location requires a password to edit if value is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location#verified_script_execution SyntheticsPrivateLocation#verified_script_execution}
    */
    readonly verifiedScriptExecution?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location newrelic_synthetics_private_location}
*/
export declare class SyntheticsPrivateLocation extends cdktf.TerraformResource {
    static readonly tfResourceType = "newrelic_synthetics_private_location";
    /**
    * Create a new {@link https://registry.terraform.io/providers/newrelic/newrelic/3.27.0/docs/resources/synthetics_private_location newrelic_synthetics_private_location} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SyntheticsPrivateLocationConfig
    */
    constructor(scope: Construct, id: string, config: SyntheticsPrivateLocationConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    get domainId(): string;
    get guid(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get key(): string;
    get locationId(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _verifiedScriptExecution?;
    get verifiedScriptExecution(): boolean | cdktf.IResolvable;
    set verifiedScriptExecution(value: boolean | cdktf.IResolvable);
    resetVerifiedScriptExecution(): void;
    get verifiedScriptExecutionInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
